# defs-Rfin.gnu   2009-01-24  S.J. Ormiston
#-------------------------------------------------------------------#
# Definitions of Rectangular fin parameters
#-------------------------------------------------------------------#
   Ac(w,t)  = w*t
   P(w,t)   = 2.0* (w + t)
#
#-------------------------------------------------------------------#
   Theta_b = T_b - T_inf
   Theta_L = T_L - T_inf
#
   m(h,k,w,t) = sqrt( h * P(w,t) / ( k * Ac(w,t) ) )
   M(h,k,w,t) = sqrt( h * P(w,t) * k * Ac(w,t) ) * Theta_b
#-------------------------------------------------------------------#
#
# Fin temperature functions
# (specific to rectangular fins only because of w,t in m and M)
#-------------------------------------------------------------------#
#
#--------+
# Case A |
#--------+
   Theta_rfin_a(x,h,k,w,t) = \
    ( cosh( m(h,k,w,t)*(L-x) ) + \
      (h/(m(h,k,w,t)*k)) * sinh( m(h,k,w,t)*(L-x) ) )/ \
    ( cosh( m(h,k,w,t)*L )     + \
      (h/(m(h,k,w,t)*k)) * sinh( m(h,k,w,t)*L ) )
#
   T_rfin_a(x,h,k,w,t) = T_inf + Theta_b * Theta_rfin_a(x,h,k,w,t)
#
#-------------------------------------------------------------------#
#
#--------+
# Case B |
#--------+
   Theta_rfin_b (x,h,k,w,t) =   cosh( m(h,k,w,t)*(L-x) )/ \
                                cosh( m(h,k,w,t)*L )
#
   T_rfin_b (x,h,k,w,t) = T_inf + Theta_b * Theta_rfin_b(x,h,k,w,t)
#
#-------------------------------------------------------------------#
#
#--------+
# Case C |
#--------+
   Theta_rfin_c (x,h,k,w,t) = \
    ( (Theta_L/Theta_b)*sinh( m(h,k,w,t)*x ) + sinh( m(h,k,w,t)*(L-x) ) )/ \
      sinh( m(h,k,w,t)*L )
#
   T_rfin_c(x,h,k,w,t) = T_inf + Theta_b * Theta_rfin_c(x,h,k,w,t)
#
#-------------------------------------------------------------------#
#
#--------+
# Case D |
#--------+
   Theta_rfin_d (x,h,k,w,t) = exp( - m(h,k,w,t)*x )
#
   T_rfin_d(x,h,k,w,t) = T_inf + Theta_b * Theta_rfin_d(x,h,k,w,t)
#
#-------------------------------------------------------------------#
