# plot-Cfin-A.gnu  2009-01-24  S.J. Ormiston
#------------------------------------------------------------------#
# plot circular fin case A in various ways
#------------------------------------------------------------------#
#
# set variables needed by the definitions
#
   T_b = 120.0; T_inf = 20.0; T_L = 50.0
   L = 0.15; h = 20; k = 200; d = 0.005
#
# read in definitions needed
#
   load "defs-Cfin.gnu"   # circular fin definitions
#
   load "defs-lines.gnu"  # line definitions
#
# Define shortcuts used in the legend
#
   xk = 0.10; yk = 35
   xl = 0.0025; yl = 70
   xt = xl; yt = yl
   yl1=yl-8;  yl2=yl-15; yl3=yl-20; yl4=yl-25
   yl5=yl-30; yl6=yl-35; yl7=yl-40; yl8=yl-45; yl9=yl-50
#
   t24= "Times,24"
   h18= "Helvetica,18"
   h14= "Helvetica,14"
#------------------------------------------------------------------#
# axis details
#
   set xlabel 'x [m]'
   set xrange [0:L]
   set xtics 0, 0.05,L
   set mxtics 5
#
   set ylabel 'Temperature [deg C]'
   set yrange [T_inf: T_b]
   set ytics T_inf, 10, T_b
   set mytics 2
#
# legend location
#
   set key xk, yk
#------------------------------------------------------------------#
#---------+
# vary h  |
#---------+
   L = 0.15; h = 20; k = 200; d = 0.005 #reset defaults
#
   set nolabel
   set label "Circular Fin"                  at xt,yt  font t24
   set label "Case A: varying h"             at xl,yl1 font h18
#
   set label sprintf("T_b = %5.1f [deg C]"  , T_b)   at xl,yl2 font h14
   set label sprintf("T_inf = %5.1f [deg C]", T_inf) at xl,yl3 font h14
#T_L label not used
#
#h label not used
   set label sprintf("k = %5.1f [W/m K]", k) at xl,yl6 font h14
   set label sprintf("d = %5.3f [m]"    , d) at xl,yl7 font h14
   set label sprintf("L = %4.2f [m]"    , L) at xl,yl8 font h14
#
#---------------------------------------------------------------------#
   plot h=5,  T_cfin_a(x,h,k,d) title "h=5  [W/m**2 K]" w lines ls 1,\
        h=10, T_cfin_a(x,h,k,d) title "h=10 [W/m**2 K]" w lines ls 2,\
        h=20, T_cfin_a(x,h,k,d) title "h=20 [W/m**2 K]" w lines ls 3,\
        h=40, T_cfin_a(x,h,k,d) title "h=40 [W/m**2 K]" w lines ls 4
#---------------------------------------------------------------------#
# save plot to colour Postscript using a custom gnuplot script file
   call "./Save-Plot.gnu" 2 "cfin-a-h"  #save the plot as a landscape color PS
#
pause -1 "Hit return to continue"
#=====================================================================#
#---------+
# vary k  |
#---------+
#
   L = 0.15; h = 20; k = 200; d = 0.005 #reset defaults
#
   set nolabel
   set label "Circular Fin"                  at xt,yt  font t24
   set label "Case A: varying k"             at xl,yl1 font h18
#
   set label sprintf("T_b = %5.1f [deg C]"  , T_b)   at xl,yl2 font h14
   set label sprintf("T_inf = %5.1f [deg C]", T_inf) at xl,yl3 font h14
#T_L label not used
#
   set label sprintf("h = %4.1f [W/m K]", h) at xl,yl5 font h14
#k label not used
   set label sprintf("d = %5.3f [m]"    , d) at xl,yl7 font h14
   set label sprintf("L = %4.2f [m]"    , L) at xl,yl8 font h14
#
#---------------------------------------------------------------------#
   plot k=50,  T_cfin_a(x,h,k,d) title "k= 50 [W/m K]" w lines ls 1,\
        k=100, T_cfin_a(x,h,k,d) title "k=100 [W/m K]" w lines ls 2,\
        k=200, T_cfin_a(x,h,k,d) title "k=200 [W/m K]" w lines ls 3,\
        k=400, T_cfin_a(x,h,k,d) title "k=400 [W/m K]" w lines ls 4
#---------------------------------------------------------------------#
# save plot to colour Postscript using a custom gnuplot script file
   call "./Save-Plot.gnu" 2 "cfin-a-k"  #save the plot as a landscape color PS
#
pause -1 "Hit return to continue"
#=====================================================================#
#---------+
# vary d  |
#---------+
#
   L = 0.15; h = 20; k = 200; d = 0.005 #reset defaults
#
   set nolabel
   set label "Circular Fin"                  at xt,yt font t24
   set label "Case A: varying d"             at xl,yl1 font h18
#
   set label sprintf("T_b = %5.1f [deg C]"  , T_b)   at xl,yl2 font h14
   set label sprintf("T_inf = %5.1f [deg C]", T_inf) at xl,yl3 font h14
#T_L label not used
#
   set label sprintf("h = %4.1f [W/m K]", h) at xl,yl5 font h14
   set label sprintf("k = %5.1f [W/m K]", k) at xl,yl6 font h14
#d label not used
   set label sprintf("L = %4.2f [m]"    , L) at xl,yl8 font h14
#
#---------------------------------------------------------------------#
   plot d=0.002, T_cfin_a(x,h,k,d) title "d=0.002 [m]" w lines ls 1,\
        d=0.005, T_cfin_a(x,h,k,d) title "d=0.005 [m]" w lines ls 2,\
        d=0.010, T_cfin_a(x,h,k,d) title "d=0.010 [m]" w lines ls 3,\
        d=0.020, T_cfin_a(x,h,k,d) title "d=0.020 [m]" w lines ls 4
#---------------------------------------------------------------------#
# save plot to colour Postscript using a custom gnuplot script file
   call "./Save-Plot.gnu" 2 "cfin-a-d"  # save the plot as a landscape color PS
#
pause -1 "Hit return to continue"
#=====================================================================#
