# plot-Rfin-two-lengths.gnu  2009-01-24 S.J. Ormiston
#------------------------------------------------------------------#
# plot rectangular fin all cases for two lengths
#
# set variables needed by the definitions
#
   T_b = 120.0; T_inf = 20.0; T_L = 50.0
   L = 0.15; h = 20; k = 200; w = 0.20; t = 0.006
#
# read in definitions needed
#
   load "defs-Rfin.gnu"   # rectangular fin definitions
#
   load "defs-lines.gnu"  # plotting line definitions
#
# Define shortcuts used in the legend (general settings)
#
   t24= "Times,24"
   h18= "Helvetica,18"
   h14= "Helvetica,14"
#
# axis details (general settings)
#
   set xlabel 'x [m]'
#
   set ylabel 'Temperature [deg C]'
   set yrange [T_inf: T_b]
   set ytics T_inf, 10, T_b
   set mytics 2
#-----------------------------------#
# vary L
#
   L = 0.15; h = 20; k = 200; w = 0.20; t = 0.006 #reset defaults
#
#-----------+
# Short fin |
#-----------+
#
   L=0.075
#
# do x-axis set up after L change
#
   set xrange [0:L]
   set xtics 0, 0.025,L
   set mxtics 5
#
# do key set up after x range change
#
   xk = 0.05; yk = 40
   set key xk, yk
#
   xl = 0.0025; yl = 75
   xt = xl; yt = yl
   yl1=yl-8;  yl2=yl-15; yl3=yl-20; yl4=yl-25
   yl5=yl-30; yl6=yl-35; yl7=yl-40; yl8=yl-45; yl9=yl-50
#
   set nolabel
   set label "Rectangular Fin"               at xt,yt  font t24
   set label "Short fin"                     at xl,yl1 font h18
#
   set label sprintf("T_b = %5.1f [deg C]"  , T_b)   at xl,yl2 font h14
   set label sprintf("T_inf = %5.1f [deg C]", T_inf) at xl,yl3 font h14
   set label sprintf("T_L = %5.1f [deg C]"  , T_L)   at xl,yl4 font h14
#
   set label sprintf("h = %4.1f [W/m K]", h) at xl,yl5 font h14
   set label sprintf("k = %5.1f [W/m K]", k) at xl,yl6 font h14
   set label sprintf("w = %4.2f [m]"    , w) at xl,yl7 font h14
   set label sprintf("t = %5.3f [m]"    , t) at xl,yl8 font h14
   set label sprintf("L = %5.3f [m]"    , L) at xl,yl9 font h14
#
#---------------------------------------------------------------------#
   plot T_rfin_a(x,h,k,w,t) title "Case A (convection at tip)" w lines ls 1,\
        T_rfin_b(x,h,k,w,t) title "Case B (adiabatic at tip) " w lines ls 2,\
        T_rfin_c(x,h,k,w,t) title "Case C (T_L specified)    " w lines ls 3,\
        T_rfin_d(x,h,k,w,t) title "Case D (infinite length)  " w lines ls 4
#---------------------------------------------------------------------#
# save plot to colour Postscript using a custom gnuplot script file
   call "./Save-Plot.gnu" 2 "rfin-tl-s" #save the plot as a landscape color PS
#
pause -1 "Hit return to continue"
#=====================================================================#
#-----------+
# Long fin  |
#-----------+
#
   L=0.60
#
# do x-axis set up after L change
#
   set xrange [0:L]
   set xtics 0, 0.05,L
   set mxtics 5
#
# do key set up after x range change
#
   xk = 0.25; yk = 40
   set key xk, yk
#
   xl = 0.25; yl = 105
   xt = xl; yt = yl
   yl1=yl-8;  yl2=yl-15; yl3=yl-20; yl4=yl-25
   yl5=yl-30; yl6=yl-35; yl7=yl-40; yl8=yl-45; yl9=yl-50
#
   set nolabel
   set label "Rectangular Fin"               at xt,yt  font t24
   set label "Long fin"                      at xl,yl1 font h18
#
   set label sprintf("T_b = %5.1f [deg C]"  , T_b)   at xl,yl2 font h14
   set label sprintf("T_inf = %5.1f [deg C]", T_inf) at xl,yl3 font h14
   set label sprintf("T_L = %5.1f [deg C]"  , T_L)   at xl,yl4 font h14
#
   set label sprintf("h = %4.1f [W/m K]", h) at xl,yl5 font h14
   set label sprintf("k = %5.1f [W/m K]", k) at xl,yl6 font h14
   set label sprintf("w = %4.2f [m]"    , w) at xl,yl7 font h14
   set label sprintf("t = %5.3f [m]"    , t) at xl,yl8 font h14
   set label sprintf("L = %5.3f [m]"    , L) at xl,yl9 font h14
#
#---------------------------------------------------------------------#
   plot T_rfin_a(x,h,k,w,t) title "Case A (convection at tip)" w lines ls 1,\
        T_rfin_b(x,h,k,w,t) title "Case B (adiabatic at tip) " w lines ls 2,\
        T_rfin_c(x,h,k,w,t) title "Case C (T_L specified)    " w lines ls 3,\
        T_rfin_d(x,h,k,w,t) title "Case D (infinite length)  " w lines ls 4
#---------------------------------------------------------------------#
# save plot to colour Postscript using a custom gnuplot script file
   call "./Save-Plot.gnu" 2 "rfin-tl-l" #save the plot as a landscape color PS
#
##pause -1 "Hit return to continue"
#=====================================================================#
